==> digikam-3.0.0.tar.bz2: digikam-3.0.0/extra/kipi-plugins/dngconverter/plugin/kipiplugin_dngconverter.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=DNGConverter
Name=DNGConverter
Name[ast]=DNGConverter
Name[bg]=Конвертор към DNG
Name[bs]=DNG konvertor
Name[ca]=DNGConverter
Name[ca@valencia]=DNGConverter
Name[cs]=DNGConverter
Name[da]=DNGConverter
Name[de]=DNGkonverter
Name[el]=Μετατροπέας DNG
Name[en_GB]=DNGConverter
Name[es]=Conversor para DNG
Name[et]=DNG teisendaja
Name[eu]=DNG bihurtzailea
Name[fi]=DNGConverter
Name[fr]=Convertisseur DNG
Name[ga]=DNGConverter
Name[gl]=DNGConverter
Name[he]=ממיר DNG
Name[hne]=डीएनजी-कनवर्टर
Name[hu]=DNG átalakító
Name[is]=DNGumbreytir
Name[it]=Convertitore DNG
Name[ja]=DNGConverter
Name[km]=DNGConverter
Name[lv]=DNGConverter
Name[nb]=DNG-omformer
Name[nds]=DNG-Wanneln
Name[nl]=DNG-convertor
Name[pa]=DNGConverter
Name[pl]=DNGConverter
Name[pt]=Conversão para DNG
Name[pt_BR]=Conversor DNG
Name[ro]=Convertor DNG
Name[ru]=Преобразование в DNG
Name[sk]=DNG konverzia
Name[sl]=DNGConverter
Name[sq]=DNGConverter
Name[sv]=DNG-konvertering
Name[th]=แปลงภาพแบบ DNG
Name[tr]=DNG Dönüştürücü
Name[uk]=DNGConverter
Name[x-test]=xxDNGConverterxx
Name[zh_CN]=DNG 转换器
Name[zh_TW]=DNG 轉換程式
Comment=A tool to convert Raw Image to Digital NeGative
Comment[ast]=Una ferramienta pa convertir les imáxenes RAW en Negativu Dixital
Comment[bg]=Инструмент за конвертиране на изображения от RAW към DNG (Digital NeGative)
Comment[bs]=Alat za konvertovanje Raw slika u Digital NeGative
Comment[ca]=Una eina per a convertir imatges RAW a «Digital NeGative»
Comment[ca@valencia]=Una eina per a convertir imatges RAW a «Digital NeGative»
Comment[cs]=Nástroj pro převod RAW obrázků do Digital NeGative
Comment[da]=Et værktøj til at konvertere RAW-billede til "Digital NeGative"
Comment[de]=Ein Werkzeug, um Kamerarohbilder nach Digital NeGativ zu konvertieren.
Comment[el]=Εργαλείο για τη μετατροπή RAW εικόνων φωτογραφικής σε Digital NeGative
Comment[en_GB]=A tool to convert Raw Image to Digital NeGative
Comment[es]=Una herramienta para convertir imágenes RAW en Digital NeGative
Comment[et]=Tööriist toorpiltide teisendamiseks Digital NeGative vormingusse
Comment[eu]=Kameren irudi gordinak Digital NeGative formatura bihurtzeko tresna
Comment[fi]=Työkalu joka muuntaa Raw Image muodosta Digital NeGative -muotoon
Comment[fr]=Outil de conversion d'image RAW en Digital NeGative
Comment[gl]=Unha ferramenta para converter imaxes Raw en Digital NeGative
Comment[he]=כלי להמרת תמונות RAW ל-Digital Negative
Comment[hne]=रा फोटू ल डिजिटल नेगेटिव मं बैच मं बदले के एक औजार
Comment[hu]=Egy eszköz Raw képek átalakításához Digital NeGative formátumba
Comment[is]=Verkfæri til að umbreyta RAW-myndum í Digital NeGative
Comment[it]=Uno strumento per convertire immagini raw nel formato Digital NeGative
Comment[ja]=RAW 画像を DNG (Digital Negative) に変換するツール
Comment[km]=ឧបករណ៍​ត្រូវ​បម្លែង​រូបភាព​ដើម​ទៅជា NeGative ឌីជីថល
Comment[lv]=Rīks RAW attēlu pārveidošana uz Digital NeGative
Comment[nb]=Et verktøy som omformer RAW-bilder til Digital NeGative (DNG)
Comment[nds]=En Warktüüch, mit dat sik Rohbiller in na Digitaal NeGativen wanneln laat
Comment[nl]=Een hulpmiddel om een raw-afbeelding te converteren naar een digitaal negatief
Comment[pa]=ਰਾਅ ਚਿੱਤਰਾਂ ਨੂ ਡਿਜ਼ਿਟਲ ਨੈਗਟਿਵ ਵਿੱਚ ਬਦਲਣ ਵਾਲਾ ਟੂਲ
Comment[pl]=Narzędzie do przekształcania obrazów Raw do Digital NeGative
Comment[pt]=Uma ferramenta de conversão em lote de imagens RAW em DNG
Comment[pt_BR]=Uma ferramenta para converter imagens RAW para DNG (Digital NeGative)
Comment[ro]=O unealtă pentru convertirea imaginilor din RAW în Digital NeGative
Comment[ru]=Инструмент для преобразования изображений RAW в формат DNG
Comment[sk]=Nástroj na konverziu RAW obrázku na Digital NeGative
Comment[sl]=Orodje za pretvorbo grobih slik v obliko Digital NeGative
Comment[sq]=Një mjet për të konvertuar imazhet Raw në Digital NeGative
Comment[sv]=Ett verktyg för att konvertera obehandlade bilder till digitala negativ (DNG)
Comment[th]=เครื่องมือในการแปลงภาพแบบ Raw ไปเป็น Digital NeGative
Comment[tr]=Ham Resmi Dijital Negatife dönüştürmek için bir araç
Comment[uk]=Інструмент для пакетного перетворення зображень цифрових негативів на DNG (Digital NeGative)
Comment[x-test]=xxA tool to convert Raw Image to Digital NeGativexx
Comment[zh_CN]=一个转换 RAW 图像为 Digital NeGative 的工具
Comment[zh_TW]=將 Raw 影像轉換成數位負片 (Digital NeGative) 的工具
Type=Service
Icon=dngconverter
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_dngconverter
X-KIPI-PluginCategories=Batch
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Gilles Caulier, caulier dot gilles at gmail dot com

==> digikam-4.6.0.tar.bz2: digikam-4.6.0/extra/kipi-plugins/dngconverter/plugin/kipiplugin_dngconverter.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=DNGConverter
Name=DNGConverter
Name[ast]=DNGConverter
Name[bg]=Конвертор към DNG
Name[bs]=DNG konvertor
Name[ca]=DNGConverter
Name[ca@valencia]=DNGConverter
Name[cs]=DNGConverter
Name[da]=DNGConverter
Name[de]=DNGkonverter
Name[el]=Μετατροπέας DNG
Name[en_GB]=DNGConverter
Name[es]=Conversor para DNG
Name[et]=DNG teisendaja
Name[eu]=DNG bihurtzailea
Name[fi]=DNG-muunnin
Name[fr]=Convertisseur « DNG »
Name[ga]=DNGConverter
Name[gl]=DNGConverter
Name[he]=ממיר DNG
Name[hne]=डीएनजी-कनवर्टर
Name[hu]=DNG átalakító
Name[is]=DNGumbreytir
Name[it]=Convertitore DNG
Name[ja]=DNGConverter
Name[km]=DNGConverter
Name[lv]=DNGConverter
Name[nb]=DNG-omformer
Name[nds]=DNG-Wanneln
Name[nl]=DNG-convertor
Name[pa]=DNGConverter
Name[pl]=DNGConverter
Name[pt]=Conversão para DNG
Name[pt_BR]=Conversor DNG
Name[ro]=Convertor DNG
Name[ru]=Преобразование в DNG
Name[sk]=DNG konverzia
Name[sl]=DNGConverter
Name[sq]=DNGConverter
Name[sv]=DNG-konvertering
Name[th]=แปลงภาพแบบ DNG
Name[tr]=DNG Dönüştürücü
Name[ug]=DNGConverter
Name[uk]=DNGConverter
Name[x-test]=xxDNGConverterxx
Name[zh_CN]=DNG 转换器
Name[zh_TW]=DNG 轉換程式
Comment=A tool to convert Raw Image to Digital NeGative
Comment[ast]=Una ferramienta pa convertir les imáxenes RAW en Negativu Dixital
Comment[bg]=Инструмент за конвертиране на изображения от RAW към DNG (Digital NeGative)
Comment[bs]=Alat za konvertovanje Raw slika u Digital NeGative
Comment[ca]=Una eina per a convertir imatges RAW a «Digital NeGative»
Comment[ca@valencia]=Una eina per a convertir imatges RAW a «Digital NeGative»
Comment[cs]=Nástroj pro převod RAW obrázků do Digital NeGative
Comment[da]=Et værktøj til at konvertere RAW-billede til "Digital NeGative"
Comment[de]=Ein Werkzeug, um Kamerarohbilder nach Digital NeGativ zu konvertieren.
Comment[el]=Εργαλείο για τη μετατροπή RAW εικόνων φωτογραφικής σε Digital NeGative
Comment[en_GB]=A tool to convert Raw Image to Digital NeGative
Comment[es]=Una herramienta para convertir imágenes RAW en Digital NeGative
Comment[et]=Tööriist toorpiltide teisendamiseks Digital NeGative vormingusse
Comment[eu]=Kameren irudi gordinak Digital NeGative formatura bihurtzeko tresna
Comment[fi]=Raw-kuvien muuntaminen Digital NeGative -muotoon
Comment[fr]=Outil de conversion d'image de format « RAW » en « Digital NeGative »
Comment[gl]=Unha ferramenta para converter imaxes Raw en Digital NeGative
Comment[he]=כלי להמרת תמונות RAW ל-Digital Negative
Comment[hne]=रा फोटू ल डिजिटल नेगेटिव मं बैच मं बदले के एक औजार
Comment[hu]=Egy eszköz Raw képek átalakításához Digital NeGative formátumba
Comment[is]=Verkfæri til að umbreyta RAW-myndum í Digital NeGative
Comment[it]=Uno strumento per convertire immagini raw nel formato Digital NeGative
Comment[ja]=RAW 画像を DNG (Digital Negative) に変換するツール
Comment[km]=ឧបករណ៍​ត្រូវ​បម្លែង​រូបភាព​ដើម​ទៅជា NeGative ឌីជីថល
Comment[lv]=Rīks RAW attēlu pārveidošana uz Digital NeGative
Comment[nb]=Et verktøy som omformer RAW-bilder til Digital NeGative (DNG)
Comment[nds]=En Warktüüch, mit dat sik Rohbiller in na Digitaal NeGativen wanneln laat
Comment[nl]=Een hulpmiddel om een raw-afbeelding te converteren naar een digitaal negatief
Comment[pa]=ਰਾਅ ਚਿੱਤਰਾਂ ਨੂ ਡਿਜ਼ਿਟਲ ਨੈਗਟਿਵ ਵਿੱਚ ਬਦਲਣ ਵਾਲਾ ਟੂਲ
Comment[pl]=Narzędzie do przekształcania obrazów Raw do Digital NeGative
Comment[pt]=Uma ferramenta de conversão em lote de imagens RAW em DNG
Comment[pt_BR]=Ferramenta para conversão de imagens RAW para DNG (Digital NeGative)
Comment[ro]=O unealtă pentru convertirea imaginilor din RAW în Digital NeGative
Comment[ru]=Инструмент для преобразования изображений RAW в формат DNG
Comment[sk]=Nástroj na konverziu RAW obrázku na Digital NeGative
Comment[sl]=Orodje za pretvorbo grobih slik v obliko Digital NeGative
Comment[sq]=Një mjet për të konvertuar imazhet Raw në Digital NeGative
Comment[sv]=Ett verktyg för att konvertera obehandlade bilder till digitala negativ (DNG)
Comment[th]=เครื่องมือในการแปลงภาพแบบ Raw ไปเป็น Digital NeGative
Comment[tr]=Ham Resmi Dijital Negatife dönüştürmek için bir araç
Comment[uk]=Інструмент для пакетного перетворення зображень цифрових негативів на DNG (Digital NeGative)
Comment[x-test]=xxA tool to convert Raw Image to Digital NeGativexx
Comment[zh_CN]=一个转换 RAW 图像为 Digital NeGative 的工具
Comment[zh_TW]=將 Raw 影像轉換成數位負片 (Digital NeGative) 的工具
Type=Service
Icon=kipi-dngconverter
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_dngconverter
X-KIPI-PluginCategories=Batch
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Gilles Caulier, caulier dot gilles at gmail dot com
